==> zio-aws-keyspaces_2.12-5.17.204.1-sources.jar: zio/aws/keyspaces/model/CreateKeyspaceRequest.scala <==
package zio.aws.keyspaces.model
import zio.aws.keyspaces.model.primitives.KeyspaceName
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateKeyspaceRequest(
    keyspaceName: KeyspaceName,
    tags: Optional[Iterable[zio.aws.keyspaces.model.Tag]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.keyspaces.model.CreateKeyspaceRequest = {
    import CreateKeyspaceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.keyspaces.model.CreateKeyspaceRequest
      .builder()
      .keyspaceName(KeyspaceName.unwrap(keyspaceName): java.lang.String)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.keyspaces.model.CreateKeyspaceRequest.ReadOnly =
    zio.aws.keyspaces.model.CreateKeyspaceRequest.wrap(buildAwsValue())
}
object CreateKeyspaceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.keyspaces.model.CreateKeyspaceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.keyspaces.model.CreateKeyspaceRequest =
      zio.aws.keyspaces.model.CreateKeyspaceRequest(
        keyspaceName,
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def keyspaceName: KeyspaceName
    def tags: Optional[List[zio.aws.keyspaces.model.Tag.ReadOnly]]
    def getKeyspaceName: ZIO[Any, Nothing, KeyspaceName] =
      ZIO.succeed(keyspaceName)
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.keyspaces.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.keyspaces.model.CreateKeyspaceRequest
  ) extends zio.aws.keyspaces.model.CreateKeyspaceRequest.ReadOnly {
    override val keyspaceName: KeyspaceName =
      zio.aws.keyspaces.model.primitives.KeyspaceName(impl.keyspaceName())
    override val tags: Optional[List[zio.aws.keyspaces.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.keyspaces.model.Tag.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.keyspaces.model.CreateKeyspaceRequest
  ): zio.aws.keyspaces.model.CreateKeyspaceRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-keyspaces_2.13-5.17.158.2-sources.jar: zio/aws/keyspaces/model/CreateKeyspaceRequest.scala <==
package zio.aws.keyspaces.model
import zio.aws.keyspaces.model.primitives.KeyspaceName
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateKeyspaceRequest(
    keyspaceName: KeyspaceName,
    tags: Option[Iterable[zio.aws.keyspaces.model.Tag]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.keyspaces.model.CreateKeyspaceRequest = {
    import CreateKeyspaceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.keyspaces.model.CreateKeyspaceRequest
      .builder()
      .keyspaceName(KeyspaceName.unwrap(keyspaceName): java.lang.String)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.keyspaces.model.CreateKeyspaceRequest.ReadOnly =
    zio.aws.keyspaces.model.CreateKeyspaceRequest.wrap(buildAwsValue())
}
object CreateKeyspaceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.keyspaces.model.CreateKeyspaceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.keyspaces.model.CreateKeyspaceRequest =
      zio.aws.keyspaces.model.CreateKeyspaceRequest(
        keyspaceName,
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def keyspaceName: KeyspaceName
    def tags: Option[List[zio.aws.keyspaces.model.Tag.ReadOnly]]
    def getKeyspaceName: ZIO[Any, Nothing, KeyspaceName] =
      ZIO.succeed(keyspaceName)
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.keyspaces.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.keyspaces.model.CreateKeyspaceRequest
  ) extends zio.aws.keyspaces.model.CreateKeyspaceRequest.ReadOnly {
    override val keyspaceName: KeyspaceName =
      zio.aws.keyspaces.model.primitives.KeyspaceName(impl.keyspaceName())
    override val tags: Option[List[zio.aws.keyspaces.model.Tag.ReadOnly]] =
      scala
        .Option(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.keyspaces.model.Tag.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.keyspaces.model.CreateKeyspaceRequest
  ): zio.aws.keyspaces.model.CreateKeyspaceRequest.ReadOnly = new Wrapper(impl)
}
